@@ -37,6 +37,7 @@ omega1_and_tau <- function(g) {
 #' @export
 halfPeriods <- function(g2g3) {
   stopifnot(isComplexPair(g2g3))
+  g2g3 <- as.complex(g2g3)
   omega1_tau <- omega1_and_tau(g2g3)
   omega1 <- omega1_tau[1L]
   c(omega1, omega1 * omega1_tau[2L])
@@ -82,6 +83,7 @@ g_from_omega1_and_tau <- function(omega1, tau){ # used in zetaw
 #' @export
 ellipticInvariants <- function(omega1omega2) {
   stopifnot(isComplexPair(omega1omega2))
+  omega1omega2 <- as.complex(omega1omega2)
   omega1 <- omega1omega2[1L]
   tau <- omega1omega2[2L] / omega1
   if(Im(tau) <= 0) {
